<?php

namespace Drupal\intercom;

use GuzzleHttp\Exception\RequestException;
use Intercom\IntercomClient;
use Drupal\Core\Site\Settings;

/**
 * Intercom Service.
 */
class IntercomApiService {

  private $accessToken;

  /**
   * IntercomProxyClient constructor.
   */
  public function __construct() {
    $this->accessToken = Settings::get('intercom_access_token');
    if (empty($this->accessToken)) {
      $this->logError('No access_token provided.');
      return;
    }
    $this->client = new IntercomClient($this->accessToken, NULL);
  }

  /**
   * Create a user through the Intercom API.
   *
   * @param array $data
   *   The data that will be passed to Intercom.
   */
  public function createUser(array $data) {
    if (!isset($data['email'])) {
      return;
    }

    $this->client->users->create($data);
  }

  /**
   * Retrieve an Intercom user by email.
   *
   * @param string $email
   *   The email to query for.
   *
   * @return array|null
   *   An array with users found or null if no user was found.
   */
  public function getUserByEmail($email) {
    try {
      $user = $this->client->users->getUsers(["email" => $email]);
    }
    catch (RequestException $exception) {
      $user = NULL;
    }

    return $user;
  }

  /**
   * Find an Intercom user by a Drupal user id.
   *
   * @param string $user_id
   *   The Drupal user id to query for.
   *
   * @return array|null
   *   An array of users found or null if no user was found.
   */
  public function getUserByUserId($user_id) {
    try {
      $user = $this->client->users->getUsers(["user_id" => $user_id]);
    }
    catch (RequestException $exception) {
      $user = NULL;
    }

    return $user;
  }

  /**
   * Log an error.
   *
   * @param string $message
   *   The error message to log.
   * @param bool $throw_exception
   *   Whether the $message should be thrown as exception.
   *
   * @throws \Exception
   *   If $throw_exception is true.
   */
  public function logError($message, $throw_exception = FALSE) {
    $message = str_replace($this->accessToken, 'my_super_secret_access_token', $message);
    \Drupal::logger('intercom')->error($message);

    if ($throw_exception === TRUE) {
      throw new \Exception($message);
    }
  }
}
